import askvideos

# Create client
api_key = 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJrZXlOYW1lIjoidGVzdCIsImlhdCI6MTcxOTkxMDI2OCwiZXhwIjoxNzE5OTEzODY4fQ.BTDKyTCwwlDRDqpPCjMA5LPelCdrvsmIRwN1lWrfmTY'
client = askvideos.Client(api_key=api_key)

# Create an index
indices = client.list_indices()
print(indices)
exit()
index_name = 'movie_example'
client.create_index(index_name)

# List all available indexes
indices = client.list_indices()
print(indices)

# Index a video
movie_file = 'no_country_for_old_men.mp4'
transcript_path = 'no_country_for_old_men.vtt'
metadata = {
  'title': "No Country For Old Men",
  'description': "A classic thriller set in the deserts of Texas",
  'info': {}
}

results = client.index(
            index_name,
            movie_file,
            transcript_path=transcript_path)

print(results)

# Search

# Search by text
# Find scenes with cowboy hats
search_term = 'cowboy hats'

results = client.search_videos(
            index_name,
            search_term,
            top_k=10)
print(results)

# Search by image
# Find scenes with an image
image_path = 'img.jpg'

results = client.search_by_image(
            index_name,
            image_path=image_path,
            top_k=10)
print(results)


# Search by video
# Find scenes with an video
query_video_path = 'video.mp4'

results = client.search_by_video(
            index_name,
            video_path=query_video_path,
            start_seconds=10,
            end_seconds=14,
            top_k=10)
print(results)

# Answer Engine

# Answer a question
query = 'Which city is this movie set in?'
results = client.answer(
            index_name,
            query)




from setuptools import setup, find_packages

setup(
    name='askvideos',  # Replace 'your_package_name' with the name of your package
    version='0.1.9',  # Version number for your package
    author='AskVideos',  # Your name or your organization's name
    author_email='askutubeai@gmail.com',  # Your email or your organization's contact email
    description='AskVideos python library',  # A brief description of your package
    long_description=open('README.md').read(),  # A long description from your README.md
    long_description_content_type='text/markdown',  # Specifies that the long description is in Markdown
    url='https://github.com/AskYoutubeAI/askvideos-py',  # URL to your package's repository
    #packages=find_packages(exclude=('tests', 'docs')),  # Automatically find all packages in your project
    install_requires=[
        # List your project's dependencies here.
        # They will be installed by pip when your package is installed.
        # Example: 'requests>=2.19.1'
        "requests",
    ],
    python_requires='>=3.6',  # Minimum version requirement of Python
    #entry_points={
    #    'console_scripts': [
    #        # Entry points for console scripts
    #        # Example: 'your_script_name = your_package.module:function'
    #    ],
    #},
)

